@@ -10,7 +10,7 @@ using namespace std;
 using namespace Eigen;
 using namespace Rcpp;
 
-Eigen::MatrixXd XiC(int n, int k,int p, int B, double bn, int ken_sign);
+Eigen::MatrixXd XiC(int n, int k,int p, int B, double bn, int ken_sign, Eigen::MatrixXd Xi_temp);
 
 double bandwith(Eigen::MatrixXd ft, int k,int p, int d, int ken_type);
 
